@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -46,15 +46,15 @@ KDEApplicationDebugSettingPage::KDEApplicationDebugSettingPage(QWidget *parent)
     QHBoxLayout *buttonLayout = new QHBoxLayout;
     mainLayout->addLayout(buttonLayout);
 
-    mSelectAll = new QPushButton(i18n("Select All"));
-    mSelectAll->setObjectName(QStringLiteral("selectall"));
-    buttonLayout->addWidget(mSelectAll);
-    connect(mSelectAll, &QAbstractButton::clicked, this, &KDEApplicationDebugSettingPage::slotSelectAll);
+    mEnableDebug = new QPushButton(i18n("Enable All Debug"));
+    mEnableDebug->setObjectName(QStringLiteral("selectall"));
+    buttonLayout->addWidget(mEnableDebug);
+    connect(mEnableDebug, &QAbstractButton::clicked, this, &KDEApplicationDebugSettingPage::slotSelectAll);
 
-    mDeselectAll = new QPushButton(i18n("Deselect All"));
-    mDeselectAll->setObjectName(QStringLiteral("deselectall"));
-    buttonLayout->addWidget(mDeselectAll);
-    connect(mDeselectAll, &QAbstractButton::clicked, this, &KDEApplicationDebugSettingPage::slotDeselectAll);
+    mTurnOffDebug = new QPushButton(i18n("Turn Off Debug"));
+    mTurnOffDebug->setObjectName(QStringLiteral("deselectall"));
+    buttonLayout->addWidget(mTurnOffDebug);
+    connect(mTurnOffDebug, &QAbstractButton::clicked, this, &KDEApplicationDebugSettingPage::slotDeselectAll);
     mTreeListWidgetSearchLine->installEventFilter(this);
 }
 
@@ -85,17 +85,17 @@ void KDEApplicationDebugSettingPage::slotDeselectAll()
     mTreeListWidget->deSelectAllDebugCategories();
 }
 
-void KDEApplicationDebugSettingPage::fillList(const Category::List &list)
+void KDEApplicationDebugSettingPage::fillList(const LoggingCategory::List &list)
 {
     mTreeListWidget->fillList(list);
 }
 
-Category::List KDEApplicationDebugSettingPage::rules() const
+LoggingCategory::List KDEApplicationDebugSettingPage::rules() const
 {
     return mTreeListWidget->rules();
 }
 
-void KDEApplicationDebugSettingPage::insertCategories(const Category::List &list)
+void KDEApplicationDebugSettingPage::insertCategories(const LoggingCategory::List &list)
 {
     mTreeListWidget->insertCategories(list);
 }
