@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -22,7 +22,7 @@
 #define KDEAPPLICATIONDEBUGSETTINGPAGE_H
 
 #include <QWidget>
-#include "kdebugsettingsdialog.h"
+#include "loggingcategory.h"
 class QPushButton;
 class KDEApplicationTreeListWidget;
 class KTreeWidgetSearchLine;
@@ -32,9 +32,9 @@ class KDEApplicationDebugSettingPage : public QWidget
 public:
     explicit KDEApplicationDebugSettingPage(QWidget *parent = Q_NULLPTR);
     ~KDEApplicationDebugSettingPage();
-    void fillList(const Category::List &list);
-    Category::List rules() const;
-    void insertCategories(const Category::List &list);
+    void fillList(const LoggingCategory::List &list);
+    LoggingCategory::List rules() const;
+    void insertCategories(const LoggingCategory::List &list);
 protected:
     bool eventFilter(QObject *obj, QEvent *event) Q_DECL_OVERRIDE;
 
@@ -44,8 +44,8 @@ private Q_SLOTS:
 private:
     KDEApplicationTreeListWidget *mTreeListWidget;
     KTreeWidgetSearchLine *mTreeListWidgetSearchLine;
-    QPushButton *mSelectAll;
-    QPushButton *mDeselectAll;
+    QPushButton *mEnableDebug;
+    QPushButton *mTurnOffDebug;
 };
 
 #endif // KDEAPPLICATIONDEBUGSETTINGPAGE_H
